# python-daikin_cloud
Python Module to interact with Daikin Cloud NA (AirZone)


# Currently working with
*  Daikin Cloud NA (https://dknna.com/)
*  AZAI6WSPDKC WiFi Controller
*  FDMQ24RVJU Air hHndler
*  4MXL36TVJU Multizone Heat Pump Condenser

# Want to add support for
*  FTXS12LVJU Wall Mount Air Handler (Mini Split)
